package old

import (
	"database/sql"
	"fmt"
	"github.com/skobkin/magnetico/pkg/persistence"
	"net/url"
)

func OpenSqliteDb(url_ url.URL) (*sql.DB, error) {
	url_.Scheme = ""
	return sql.Open("sqlite3", url_.String())
}

func GetNumberOfTorrents(db sql.DB) (uint, error) {
	rows, err := db.Query("SELECT COUNT(id) FROM torrents;")
	if err != nil {
		return 0, err
	}
	defer rows.Close()

	if rows.Next() != true {
		return 0, fmt.Errorf("No rows returned from `SELECT COUNT(id)`")
	}

	var n *uint
	if err = rows.Scan(&n); err != nil {
		return 0, err
	}

	// If the database is empty (i.e. 0 entries in 'torrents') then the query will return nil.
	if n == nil {
		return 0, nil
	} else {
		return *n, nil
	}
}

func GetFilesForTorrent(pyDb sql.DB, torrent persistence.TorrentMetadata) ([]persistence.File, error) {
	files := make([]persistence.File, 0)

	// Selecting files for torrent
	fRows, err := pyDb.Query("SELECT f.path, f.size FROM files AS f WHERE f.torrent_id = ? ORDER BY f.id ASC;", torrent.ID)
	if err != nil {
		return files, nil
	}
	defer fRows.Close()

	for fRows.Next() {
		var file persistence.File
		err := fRows.Scan(&file.Path, &file.Size)
		if err != nil {
			return files, err
		}

		files = append(files, file)
	}

	return files, nil
}
